<template>
    <el-dialog v-if="dialogVisible" custom-class="easy-dialog" :visible.sync="dialogVisible" :show-close="false"
        top="6%" :append-to-body="true" :destroy-on-close="true">
        <!-- 关闭图标 -->
        <img class="cloes-icon" src="@/assets/img/easy-dialog/icon_tck_close@3x.png" @click="handleClose" />
        <div class="title-diy">
            <div class="title">
                {{ projectDetail.projectName }}
            </div>
        </div>
        <!-- 内容默认插槽 #01215a-->
        <div class="content-diy" v-loading="loading" element-loading-background="rgba(1, 33, 90, 1)">
            <el-descriptions class="margin-top" :column="3" border :labelStyle="{ width: '5%' }">
                <el-descriptions-item :span="3" label="项目名称">
                    {{ projectDetail.projectName }}
                </el-descriptions-item>
                <el-descriptions-item label="主责单位">
                    {{ projectDetail.unitName }}
                </el-descriptions-item>
                <el-descriptions-item label="专项小组">
                    {{ projectDetail.groupName }}
                </el-descriptions-item>
                <el-descriptions-item label="计划类型">
                    {{ getDictName('yd_jhlx', planType) }}
                </el-descriptions-item>
                <el-descriptions-item :span="3" v-for="(item, index) in planTypeDetails" :key="item.id"
                    :label="`月度进展${index + 1}`">
                    <el-descriptions class="margin-top" :column="4" border :labelStyle="{ width: '2.85%' }">
                        <el-descriptions-item label="计划月度">
                            {{ `${item.planYear}年${item.planMonth}月` }}
                        </el-descriptions-item>
                        <el-descriptions-item label="推进状态" :span="3">
                            {{ getDictName('zdxm_tjzt', item.isOver) }}
                        </el-descriptions-item>
                        <el-descriptions-item label="计划内容" :span="4">
                            {{ item.planContent }}
                        </el-descriptions-item>
                        <el-descriptions-item :span="4" :label="item.isOver == 3 ? planType == 5 ||
                            planType == 4 ? '制度成果名称' : planType == 6 ? '平台名称'
                            : planType == 7 ? '应用名称' : '已完成工作' : '已开展工作'">
                            {{ item.completedWork }}
                        </el-descriptions-item>
                        <el-descriptions-item :span="4" :label="item.isOver == 3 &&
                            (planType == 5 || planType == 4 || planType == 6 || planType == 7)
                            ? '有关详情及解决问题' : '存在问题'">
                            <div class="div-font"
                                :style="{'font-weight': statusText === '未完成' ? '700' : '500', 'color': statusText === '未完成' ? '#f43308' : '#fff' }">
                                {{ item.problems }}</div>
                        </el-descriptions-item>
                        <!-- <el-descriptions-item :span="4" label="下一步工作计划">
                            {{ item.workPlan }}
                        </el-descriptions-item> -->
                        <el-descriptions-item label="附件">
                            <FileList :fileList="item.defaultFileList"
                                :classified="item.classified == '文件涉密，已通过内网邮件上传。'">
                            </FileList>
                        </el-descriptions-item>
                    </el-descriptions>
                </el-descriptions-item>
            </el-descriptions>


        </div>
    </el-dialog>
</template>

<script>
import utils from '@/utils.js'
import apiList from '@/api/bigScreen/majorView.js'
import FileList from '@/components/uploadFile/FileList.vue'
export default {
    name: 'monthlyProgressDialog',
    components: {
        FileList,
    },
    data() {
        return {
            title: '',
            dialogVisible: false,
            projectDetail: null,
            planType: '',
            planTypeDetails: [],
            loading: false,
            statusText: ''
        }
    },
    beforeDestroy() {
        this.$bus.$off('changeDate')
    },
    mounted() {
    },
    methods: {
        open(item, index) {
            console.log(item);

            this.loading = true
            this.projectDetail = item
            this.getDetailsByType(item, index)
            this.dialogVisible = true
        },
        getDetailsByType(item, index) {
            let { year, month } = JSON.parse(sessionStorage.getItem('searchDate'))
            let { planType, status, projectId, statusText } = item[`target${index}`]
            this.planType = planType
            this.statusText = statusText
            let data = {
                year,
                month,
                planType,
                status,
                projectId
            }
            apiList.getDetailsByType(data, res => {
                if (res && res.data.length) {
                    this.planTypeDetails = res.data
                } else {
                    this.planTypeDetails = []
                }
                this.loading = false
            })
        },
        getDictName(code, value) {
            return utils.getDictName(code, value)
        },
        handleClose() {
            this.projectDetail = null
            this.planType = ''
            this.planTypeDetails = []
            this.dialogVisible = false
        },
    },
}
</script>

<style lang="scss" scoped>
.div-font {
    font-size: 16px !important;
    font-family:'Gill Sans', 'Gill Sans MT', Calibri, 'Trebuchet MS', sans-serif;
}
/deep/.file-item {
    border: none;

    .file_name {
        min-width: 70%;
        font-size: 16px !important;
        height: auto;
    }

    a {
        .el-link--inner {
            font-size: 16px !important;
        }
    }

    &:hover {
        background: rgba(2, 115, 233, 0.3);

        .file_name {
            color: #fff;
        }
    }
}

/deep/.el-input--suffix {
    text-align: center;
    border: none;

    .el-input__inner {
        border: none;
        background: transparent;
        color: #fff;
        padding: 0;
        text-align: center;
    }

    .el-select__caret {
        display: none;
    }
}

::v-deep .v-modal {
    display: none !important;
}

::v-deep .easy-dialog {
    //background: url("~@/assets/images/easy-dialog/dialog-bg.png") no-repeat;
    background-size: 100% 100%;
    box-sizing: border-box;
    border: 1px solid #0273E9;
    background-color: #01215a;
    padding-bottom: 26px;
    // height: 90vh;
    width: 80%;

    .title-diy {
        width: 100%;
        height: 50px;
        display: flex;
        justify-content: center;
        align-items: center;
        // padding-left: 24px;
        box-sizing: border-box;

        .title {
            font-size: 18px;
            font-family: Source Han Sans CN;
            font-weight: 800;
            color: #FFFFFF;
            position: relative;
            text-shadow: 0px 0px 0.83333vw #266bf2;
        }

        .title::after,
        .title::before {
            content: '';
            position: absolute;
            top: 50%;
            width: 40px;
            height: 4px;
            transform: translateY(-50%);
        }

        .title::before {
            right: calc(100% + 20px);
            background: url('~@/assets/img/bigScreen/line63.png') no-repeat center / 100% 100%;
        }

        .title::after {
            left: calc(100% + 20px);
            background: url('~@/assets/img/bigScreen/line62.png') no-repeat center / 100% 100%;
        }
    }

    .el-dialog__body {
        max-height: 90vh !important
    }




    .content-diy {
        box-sizing: border-box;
        // max-height: calc(900px - 44px - 30px);
        overflow-y: auto;
        padding: 20px 24px;
        box-sizing: border-box;
        height: 68vh;


        /* 设置滚动条的样式 */
        &::-webkit-scrollbar {
            width: 8px !important; //垂直方向上的宽
            height: 8px !important; //水平方向上的宽
        }

        /* 滚动槽 */
        &::-webkit-scrollbar-track {
            border-radius: 0;
            background-color: #01215a !important;
        }

        /* 滚动条滑块 */
        &::-webkit-scrollbar-thumb {
            border-radius: 18px;
            background-color: rgba(#fff, 0.1) !important;
        }

        /*滚动条交叉样式*/
        &::-webkit-scrollbar-corner {
            background: #01215a !important;
        }
    }

    .footer-diy {
        display: flex;
        justify-content: center;
    }

    .el-dialog__header {
        width: 0;
        height: 0;
        padding: 0;
    }

    .el-dialog__body {
        padding: 0;
    }

    .cloes-icon {
        width: 20px;
        height: 20px;
        position: absolute;
        top: 6px;
        right: 6px;
        cursor: pointer;
    }

    .decoration {
        width: 100%;
        height: 100%;
        position: absolute;
        left: 0;
        top: 0;
    }


    #trend-chart {
        width: 80%;
        height: 100%;
        margin: 0 10%;
    }
}

/deep/.el-descriptions .is-bordered .el-descriptions-item__cell {
    border-color: #245cf3;
    background: transparent;
    color: #fff;
    font-size: 16px;
    font-family:'Gill Sans', 'Gill Sans MT', Calibri, 'Trebuchet MS', sans-serif;
    div {
        font-size: 16px;
    }
}

/deep/.el-descriptions__body {
    background: transparent;
}
</style>
